@@ -6,6 +6,7 @@ trans.mat <- function(bathy,min.depth=0,max.depth=NULL) {
 	ras[bathy > min.depth] <- 0.00000001
 	ras[bathy <= min.depth] <- 1
 	if (!is.null(max.depth)) ras[bathy <= max.depth] <- 0.00000001
+	if (is.null(max.depth)) max.depth <- min(bathy, na.rm=TRUE)
 	
 	lat <- as.numeric(colnames(bathy))
 	lon <- as.numeric(rownames(bathy))
@@ -16,5 +17,6 @@ trans.mat <- function(bathy,min.depth=0,max.depth=NULL) {
 	trans <- gdistance::transition(r, transitionFunction = mean, directions = 16)
 	transC <- gdistance::geoCorrection(trans,type="c",multpl=FALSE)
 
+	transC@history <- list(min.depth, max.depth, bathy)
 	return(transC)
 }
\ No newline at end of file
